package com.ruoyi.system.mapper.projectV2;

import com.ruoyi.system.domain.projectV2.ZsyzSkDzje;

import java.util.List;

/**
 * 招商引资_省库项目_到资金额Mapper接口
 * 
 * @author boman
 * @date 2023-03-28
 */
public interface ZsyzSkDzjeMapper 
{
    /**
     * 查询招商引资_省库项目_到资金额
     * 
     * @param id 招商引资_省库项目_到资金额主键
     * @return 招商引资_省库项目_到资金额
     */
    public ZsyzSkDzje selectZsyzSkDzjeById(Long id);

    /**
     * 查询合计到资金额
     * @param id
     * @return
     */
    public Long selectCountBySkId(Long id);

    /**
     * 查询招商引资_省库项目_到资金额列表
     * 
     * @param zsyzSkDzje 招商引资_省库项目_到资金额
     * @return 招商引资_省库项目_到资金额集合
     */
    public List<ZsyzSkDzje> selectZsyzSkDzjeList(ZsyzSkDzje zsyzSkDzje);

    /**
     * 新增招商引资_省库项目_到资金额
     * 
     * @param zsyzSkDzje 招商引资_省库项目_到资金额
     * @return 结果
     */
    public int insertZsyzSkDzje(ZsyzSkDzje zsyzSkDzje);

    /**
     * 修改招商引资_省库项目_到资金额
     * 
     * @param zsyzSkDzje 招商引资_省库项目_到资金额
     * @return 结果
     */
    public int updateZsyzSkDzje(ZsyzSkDzje zsyzSkDzje);
    public int updateZsyzSkDzjeSkId(ZsyzSkDzje zsyzSkDzje);

    /**
     * 删除招商引资_省库项目_到资金额
     * 
     * @param id 招商引资_省库项目_到资金额主键
     * @return 结果
     */
    public int deleteZsyzSkDzjeById(Long id);
    public int deleteZsyzSkDzjeBySkId(Long id);

    /**
     * 批量删除招商引资_省库项目_到资金额
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteZsyzSkDzjeByIds(Long[] ids);
}
